@@ -51,47 +51,53 @@ class Eprints3XML(object):
 
     @gotep3xml
     def get_list(self, fieldname):
-        for item in self._et.find(NS['ep']+fieldname).getchildren():
-            item_details = {}
-            for field in item.getchildren():
-                if field.tag == NS['ep']+u"name":
-                    for namepart in field.getchildren():
-                        item_details[namepart.tag[len(NS['ep']):]+"name"] = namepart.text
-                else:
-                    if field.text:
-                        if not field.text.strip():
-                            item_details[field.tag[len(NS['ep']):]] = field
-                        else:
-                            item_details[field.tag[len(NS['ep']):]] = field.text
-            yield item_details
+        list_node = self._et.find(NS['ep']+fieldname)
+        if list_node != None:
+            for item in list_node.getchildren():
+                item_details = {}
+                for field in item.getchildren():
+                    if field.tag == NS['ep']+u"name":
+                        for namepart in field.getchildren():
+                            item_details[namepart.tag[len(NS['ep']):]+"name"] = namepart.text
+                    else:
+                        if field.text:
+                            if not field.text.strip():
+                                item_details[field.tag[len(NS['ep']):]] = field
+                            else:
+                                item_details[field.tag[len(NS['ep']):]] = field.text
+                yield item_details
 
     @gotep3xml
     def get_creators(self):
-        for item in self._et.find(NS['ep']+u"creators").getchildren():
-            item_details = {}
-            for field in item.getchildren():
-                if field.tag == NS['ep']+u"name":
-                    for namepart in field.getchildren():
-                        item_details[namepart.tag[len(NS['ep']):]+"name"] = namepart.text
-                else:
-                    item_details[field.tag[len(NS['ep']):]] = field.text
-            yield item_details
+        creators = self._et.find(NS['ep']+u"creators")
+        if creators != None:
+            for item in creators.getchildren():
+                item_details = {}
+                for field in item.getchildren():
+                    if field.tag == NS['ep']+u"name":
+                        for namepart in field.getchildren():
+                            item_details[namepart.tag[len(NS['ep']):]+"name"] = namepart.text
+                    else:
+                        item_details[field.tag[len(NS['ep']):]] = field.text
+                yield item_details
 
     @gotep3xml
     def get_documents(self):
-        for doc in self._et.find(NS['ep']+u"documents").getchildren():
-            doc_details = {}
-            for field in doc.getchildren():
-                if field.tag == NS['ep']+u"files":
-                    doc_details['files'] = []
-                    for file_section in field.getchildren():
-                        file_details = {}
-                        for file_field in file_section.getchildren():
-                            file_details[file_field.tag[len(NS['ep']):]] = file_field.text
-                        doc_details["files"].append(file_details)
-                else:
-                    doc_details[field.tag[len(NS['ep']):]] = field.text
-            yield doc_details
+        docs = self._et.find(NS['ep']+u"documents")
+        if docs != None:
+            for doc in docs.getchildren():
+                doc_details = {}
+                for field in doc.getchildren():
+                    if field.tag == NS['ep']+u"files":
+                        doc_details['files'] = []
+                        for file_section in field.getchildren():
+                            file_details = {}
+                            for file_field in file_section.getchildren():
+                                file_details[file_field.tag[len(NS['ep']):]] = file_field.text
+                            doc_details["files"].append(file_details)
+                    else:
+                        doc_details[field.tag[len(NS['ep']):]] = field.text
+                yield doc_details
 
     @gotep3xml
     def list_fields(self):
